# mdsisclienttools
![build](https://github.com/gbrrestoration/mds-is-client-tools/actions/workflows/ci-cd.yml/badge.svg)
[![codecov](https://codecov.io/gh/gbrrestoration/mds-is-client-tools/branch/main/graph/badge.svg?token=QVMBSUJFEF)](https://codecov.io/gh/gbrrestoration/mds-is-client-tools)

Python package containing client tools to assist in accessing and using the RRAP M&DS IS APIs and services.

## Installation

```bash
$ pip install mdsisclienttools
```

## Usage

### Documentation 
[See our read-the-docs documentation here](http://mds-is-client-tools.readthedocs.io/)

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`mdsisclienttools` was created by RRAP. RRAP retains all rights to the source and it may not be reproduced, distributed, or used to create derivative works.

## Credits

`mdsisclienttools` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
